SWDEV-339113 - Update sampl codes with correct kernel coordinate (#2704)

Change-Id: Ibfc0fd285441cd3d79b312d2b739729a039a6f84
This commit is contained in:
ROCm CI Service Account
2022-06-02 17:07:52 +05:30
کامیت شده توسط GitHub
والد 7b0ed9e8d3
کامیت 5da168300f
14فایلهای تغییر یافته به همراه47 افزوده شده و 47 حذف شده
@@ -43,7 +43,7 @@ void matrixRowSum(int* input, int* output, int width) {
// Device (kernel) function
__global__ void gpuMatrixRowSum(int* input, int* output, int width) {
int index = hipBlockDim_x * hipBlockIdx_x + hipThreadIdx_x;
int index = blockDim.x * blockIdx.x + threadIdx.x;
#pragma unroll
for (int i = 0; i < width; i++) {
output[index] += input[index * width + i];